/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/

/*-- SCASEUP ---------------------------------*/
/* Converts a given string to all uppercase   */
/* Returns the length of the string converted */
/* Note: On the Sun the following include     */ 
/* statement must be included:                */ 
/*     #include <ctype.h>                     */ 
/*                                            */
/* Development History:                       */
/*  Begun: 11/25/85 - Todd King               */ 
/*          Under GH06 support.               */
/*                                            */
/*  Version:                                  */
/*     @(#)scaseup.c	1.1      (UCLA/IGPP)     03 Mar 1992           */
/*--------------------------------------------*/

#include <ctype.h> /* For islower() and toupper() */
#include <string.h> /* For strlen() */

scaseup(string)
char string[];
{
  int j,end;

  end=strlen(string);
  for(j=0;j<end;j++) if (islower(string[j])) string[j]=toupper(string[j]);
  return(end);
}

