/*---------------------------------------------------------------*/
/*   Copyright (c) 1993 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*-- MOREDATA ---------------------------------------
 Determines if there is more data to be read from the
 data pipe. Checks for the end of file condition which 
 is stored in "In.guage" as a negative number (-1).

  Entry Requirements:
     NONE

  Return Value:
     TRUE : If there is more data.
     FALSE : If no more data will be delievered.

  Developement History:
    Begun: 09/15/93 - Todd King
    Edited:04/14/94 - Gilbert Hyatt
      Now uses pipec.h as entry point into the library.
 
  Version:
      @(#)moredata.c	1.2    (UCLA/IGPP)   20 Apr 1994
-----------------------------------------------------*/
#include "pipec.h"

moredata()
{
   extern BLOCK In;

   if(In.guage == -1) return(0);
   else return(1);
}

