/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)pipec.h	1.1    (UCLA/IGPP)    20 Apr 1994
 */
/*---------------------------------------------------------------
  pipec.h

  Usage:
    Entry point for the pipec library, used by library.  The 
    fitting entry point is still highpipec.h

  History:
    Began: Gilbert Hyatt - 04/20/94
 
  ----------------------------------------------------------------*/ 

#ifndef _PIPEC_
#define _PIPEC_

#include "buf_list.h"
#include "buffblkc.h"
#include "cmdlineext.h"
#include "dfs_buffer.h"
#include "flagdefc.h"
#include "funcdefc.h"
#include "maxpipec.h"
#include "specialc.h"
#include "stddescc.h"
#include "stdpipec.h"
   
#endif /* _PIPEC_ */
