/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)cmdlinec.h	1.2    (UCLA/IGPP)    18 Mar 1994
 */
/* declarations for command line processing */
/* begun - 7/24/86 - Marco Zagha */
/* update - 2/6/87 - Marco Zagha */

#ifndef CMDLINE
#define CMDLINE

#include <stdio.h>
#define getcmdlineopt(a,b,c)	_GetCmdlineOpt(argc,argv,a,b,c)
#define initpipe()              _InitPipe(argc, argv)

  int pdbArgNumber = 1;
  int pdbFittingID = 0;    /* Fitting ID number passed by mp*/
  int pdbMessageID = 0;    /* plog message ID */
  char pdbprefix[40];
  int pdbchk_prefix = 0;  /* FALSE */
  int pdboptfile = 0;  /* FALSE */
  char pdbOptName[80];
  FILE *pdbcomfile;

  int _GetCmdlineOpt();
  int _InitPipe();

#endif /* CMDLINE */
