/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)bufferc.h	1.1    (UCLA/IGPP)    08 Jan 1992
 */
/*------------------------------------------------*/
/* C buffering routines.                          */
/*                                                */
/* Begun: Marco Zagha -  11/3/86                  */
/* Update: Marco Zagha - 6/17/87 (Dataout removed)*/
/*------------------------------------------------*/

#ifndef _BUFFER_
#define _BUFFER_

#include <stdio.h>

  int	 Buffstarted = 0;        /* 1 if buffer file has been opened */
  int	 Buffsize = 0;           /* maximum size of buffer in records */
  int	 Inbuff = 0;             /* actual number of records in the buffer */
  char   Buffname[25];           /* filename of buffer */
  FILE  *Buffptr = NULL;         /* pointer to buffer file */
  int	 Buffdesc;               /* descriptor number for buffer file*/
  int	 Currentrec = 1;         /* current record number in buffer */
  int	 Rotateindex = 1;        /* starting index of rotating buffer */

#endif /* _BUFFER_ */
