/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)lowmask.h	1.2    (UCLA/IGPP)    16 Mar 1994
 */
#ifndef _LOWMASK_
#define _LOWMASK_

/* Decalarations for the defines and structures used in 'mask'

   written: 2/24/87 - Todd King
*/

#ifdef _MSDOS
/* nothing */
#else
#include <dirent.h>
#endif

struct filemask {
  char fullmask[256];
  char dirpath[256];
  char halfmask[256];
#ifndef _MSDOS  
  DIR *dirp;  
#endif
  };

#define D_UNIQUE	1
#define D_FULL		2
#define D_SHORT		4

#endif /* _LOWMASK_ */
