/*---------------------------------------------------------------*/
/*   Copyright (c) 1992 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*-- InDataFlow -------------------------------------------- 
 Checks to see if the fitting is in a data flow.
 Returns TRUE if it is and FALSE if it is not.
 This call works only after getcmdlineopt() is
 called.
                                                           
 ENTRY REQUIREMENTS:                                       
   ARGC, ARGV                                              
                                                           
 RETURN VALUES:                                            
   1 if the line number is found; 0 otherwise              
                                                           
 Development History:                                 
	Begun:  12/03/92 - Todd King

 Version:
    @(#)InDataFlow.c	1.2   (UCLA/IGPP)   20 Apr 1994
----------------------------------------------------------*/
InDataFlow()
{
#include "pipec.h"
  return(pdbFittingID);	/* 0 if not in data flow, >0 otherwise. */
}
