/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)flagdefc.h	1.1    (UCLA/IGPP)    08 Jan 1992
 */
/* Definition of the flag values     */
/* C specific.                       */
/* Begun:    7/9/86 - Todd King      */
/* Addition: 7/30/86 - Marco Zagha   */

#ifndef FLAGDEF
#define FLAGDEF

/* Pipeline flag values */

#define INPUT		(1)
#define OUTPUT		(2)

/* Flag values for column assignment */

#define FLAGINT		(2147483000)
#define FLAGREAL	(3.4e+38)
#define FLAGDOUBLE	(1.7e+308)

#endif /* FLAGDEF */
