/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)filetype.h	1.1    (UCLA/IGPP)    08 Jan 1992
 */
/* Defines the values returned by 'filetype' upon a          */
/* successful determination of the characteristics of a file */
/*							     */
/* Written: 2/19/87 - Todd King				     */
#ifndef _FILETYPE_
#define _FILETYPE_

#define NOACCESS	1
#define NOREAD		2
#define DIRFILE		4
#define TEXTFILE	8
#define EXECFILE	16

#define FOUND_FILE	NOREAD

int	findfile();
int	filetype();

#endif /* _FILETYPE_ */
