/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)maxpipec.h	1.1    (UCLA/IGPP)     08 Jan 1992
 */
/* Definition of the maximums for the flat file and pipeline system */

#ifndef _MAXPIPE_
#define _MAXPIPE_

#define MAXLENGTH   2048	/* Maximum length of the buffer string */
				/* Must be sizeof(double)*MAXCOLS      */
#define BLKSIZE     2048	/* Maximum size of a block */
				/* should be same as MAXLENGTH so we are */
				/* Guaranteed that we get a complete record */
#define MAXCOLS      256	/* Maximum number of columns */
#define MAXOPTLEN    512	/* Maximum length of command line option */

#define MAXPARTS     1024       /* Maximum # of parts in an single option */
#define MAX_CONDUITS  20        /* Maximum number of conduits per class */
#define MAXCMD       4096       /* Maximum length of a command (including options) */
#define MAXBP         20        /* Maximum number of Blue print files */

#endif /* _MAXPIPE_ */
