
PROTOS = $(LIBOBJ:.o=.c)

all :       $(TARGET)

$(TARGET) : $(LIBOBJ)
	$(AR) $(ARFLAGS) $@ $?
	$(RANLIB)        $@

clean :
	$(RM) $(LIBOBJ) 

protos:
	$(DFSHOME)/bin/ffproto $(PROTOS)

# Implicit rules which are not part of BSD make:
.f.a:
	$(FC) -c $(FFLAGS) $<
	ar rv $@ $*.o
	rm -f $*.o
 
.f~.a:
	$(GET) -G$*.f $(GFLAGS) $<
	$(FC) -c $(FFLAGS) $*.f
	ar rv $@ $*.o
	rm -f $*.o

