/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
         %W%     (UCLA/IGPP)    %G%
 */
/* Defines those parameters needed for use with the functions    */
/* in the library 'miscc'. Also defines the return value for     */
/* functions which return something other then the default value */
/*                                                               */
/* Begun: 3/02/87 - Todd King                                    */
/* Edit : 7/23/93 - Gilbert Hyatt                                */
#ifndef miscc
#define miscc 0

#define Nulllist (char **)0
#define IO_READ      0
#define IO_WRITE     1
#define IO_ERROR     2

#define IO_2_PROGRAM 0
#define IO_2_STDIN   0
#define IO_2_STDOUT  1
#define IO_2_NULL    2
#define IO_2_FILE    3
 
/* Function prototypes */
#if defined(__STDC__) || defined(__cplusplus)
#define P_(s) s
#else
#define P_(s) ()
#endif

#ifdef __cplusplus
extern "C" {
#endif

/* TestFdReady.c */
int TestFdReady P_((int fd, int request));

#ifdef __cplusplus
}
#endif

#undef P_

#endif /* miscc */
