/*---------------------------------------------------------------*/
/*   Copyright (c) 1992 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*-----------------------------------------------------------------
  Do nothing binary conversion functions. Useful for disabling any
  conversion of numbers.

  Development History:
    Begun: 03/20/92 - Todd King

  Version:
      %W%     (UCLA/IGPP)    %G%
-----------------------------------------------------------------*/
#include "BC.h"

void 
BCNullFormat ()
{
   BCFloatToIEEE = BCDoNothing;
   BCIEEEToFloat = BCDoNothing;

   BCDoubleToIEEE = BCDoNothing;
   BCIEEEToDouble = BCDoNothing;

   BCGFloatToIEEE = BCDoNothing;
   BCIEEEToGFloat = BCDoNothing;

   BCShortToIEEE = BCDoNothing;
   BCIEEEToShort = BCDoNothing;

   BCIntegerToIEEE = BCDoNothing;
   BCIEEEToInteger = BCDoNothing;

   BCLongIntegerToIEEE = BCDoNothing;
   BCIEEEToLongInteger = BCDoNothing;

   BCCharToASCII = BCDoNothing;
   BCASCIIToChar = BCDoNothing;

   BCReverseByteOrder = BCDoNothing;
}

