/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      %W%    (UCLA/IGPP)    %G%
 */
/* Declarations for use of high level pipeline calls  */
/* Begun: 2/26/86  - Todd King                        */
/*      Under GH06 support.                           */

#ifndef _HIGHPIPE_
#define _HIGHPIPE_

#include "pipec.h"
#include "stdvarsc.h"
#include "cmdlinec.h"
#include "bufferc.h"
#include "blockc.h"
#include "timec.h"

#ifndef M_PI
#define M_PI 3.14159265358979323846
#endif

#if defined(__STDC__) || defined(__cplusplus)
int Msg_Exit (int err_num, char filler[]);
#else
int main ();
int Msg_Exit ();
#endif
 
 
#undef P_

#endif /* //_HIGHPIPE_ */
