/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)funcdefc.h	1.3    (UCLA/IGPP)    30 Apr 1993
 */
/* Declaration of function types  */
/* Written: 9/23/86 - Todd King   */
/* Modified: 6/8/87 - Marco Zagha (pread,pwrite,peof,and perrno defined) */
      

#ifndef _FUNCDEFC_
#define _FUNCDEFC_

double getcolval(), buffgetcolval();
char *getcolstr();
char *scolname(),*lcolname(),*colunits();
char *uniqname();
int colwidth(),colsort(),setdesc();
int setcolstr(),setcolval();
int setcolflag(), isflag();
int exists();
char *getFittingName();

/*  End of function type declaration  */

/* Beginning of FUNCTION translations */
#define setcolval(a,b)	_setcolval(a, (double)(b))
#define buffsetcolval(a, b, c) _buffsetcolval(a, b, (double)(c))
#define pread		read
#define pwrite		write
#define peof		close
#define perrno()	errno

/* End of function translations */

#endif /* _FUNCDEFC_ */
