/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)overlayc.h	1.1    (UCLA/IGPP)     1/8/92
 */
/*-------------------------------------------*/
/* Defines those variables used for overlays */
/* Begun: 11/4/86 - Todd King                */
/*-------------------------------------------*/
#ifndef OVERLAY
#define OVERLAY

typedef struct { char *sptr; int length; } string;

#define val(x)	(*x)
#define str(x) (x->sptr)
#define setstr(x,string) strncpy(x->sptr,string,x->length)
#define overlay(variable, colname, type) _overlay(&variable,colname,type)

#define INT	1
#define FLOAT	2
#define DOUBLE	3
#define TIME	4
#define STRING	5

#endif /* OVERLAY */
