/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)getcolval.c	1.3  (UCLA, IGPP) 20 Apr 1994 
 */
/*-- GETCOLVAL --------------------------*/
/* Gets the requested column value.      */
/* returns 0 if the column is not found. */
/* this is not to be considered an       */
/* error status since zero is also a     */
/* valid return.                         */
/*                                       */
/* Entry requirements:                   */
/*    COLNAME: The short column name for */
/*             which its value is to be  */
/*             returned.                 */
/*                                       */
/* Developement History:                 */
/*   Begun: 2/21/86 - Todd King          */
/*            Under GG74 support.        */
/*   Update: 5/7/87 - Marco Zagha        */
/*            Under GG44 support.        */
/*---------------------------------------*/
#include "pipec.h"

double 
getcolval(colname)
char colname[];
{

  extern char *Rbuffer;
  double buffgetcolval();

  return(buffgetcolval(Rbuffer, colname));
}

