/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)stddescc.h	1.1    (UCLA/IGPP)     08 Jan 1992
 */
/* Decalration of database structure for high level pipeline calls */
/* C specific.  (2/26/86) */
/* Update: 3/4/87 - Marco Zagha - EODESC definition added */

#ifndef _STDDESCC_
#define _STDDESCC_

#define DESCWIDTH	62
#define EODESC "--------------------- END OF DESCRIPTORS ---------------------"

typedef struct _desc 
   { char longcol[33];
     char shortcol[9];
     char units[17];
     char type;
     int width;
     int sort;
     int start;
     unsigned int flags;
   } DESC;
   
/* Maximum lengths + 1 */
#define DFS_LNAME     33
#define DFS_SNAME     9
#define DFS_UNITS     17

/* End of declarations */
#endif /* _STDDESCC_ */
