
/*----------------------------------------------------------------
   Creates an instance of a PATTERN structure.

   Entry Requirements:
      none.

   Return Value:
      NULL : If unable to create a new instance.
      otherwise: A pointer to a newly created PATTERN structure.

   Development History:
      Begun: 03/02/92 - Todd King

   Version:
      @(#)p_make.c	1.1    (UCLA/IGPP)   03 Mar 1992
------------------------------------------------------------------*/
#include <malloc.h>	/* malloc() */
#include <memory.h>	/* For memset() */
#include "pattern.h"

PATTERN *
pattern_make()
{
   PATTERN *p;

   p = (PATTERN *)malloc(sizeof(PATTERN));
   if(p != NULL) {
      memset(p, 0, sizeof(PATTERN));
   }
   return(p);
}
