/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)rrecord.c	1.3  (UCLA, IGPP) 20 Apr 1994 
 */
/*-- RRECORD ----------------------------*/
/* restores a data record into the given */
/* storage area. Restores an entire      */
/* record from the buffer.               */
/* The buffer must be large enough to    */
/* hold an entire record. C is unable to */
/* determine if this is true so you must */
/* insure it is.                         */
/*                                       */
/* On entry:                             */
/*   BUFFER: The buffer to place the     */
/*           record in.                  */
/*                                       */
/* Returns:                              */
/*  always zero.                         */
/*                                       */
/* History:                              */
/*  Begun: 5/86 - Todd King              */
/*            Under GH06 support.        */
/*---------------------------------------*/
rrecord(buffer)
char buffer[];
{
  extern char *Rbuffer;
  extern int Recl;

  int i;

  for(i=0;i<Recl;i++) Rbuffer[i]=buffer[i];
  return(0);
}
