/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)srecord.c	1.3  (UCLA, IGPP) 20 Apr 1994 
 */
/*-- SRECORD ----------------------------*/
/* Saves the current data record in the  */
/* given storage area. Stores uan entire */
/* record in the buffer. It is up to the */
/* user to insure that the buffer is     */
/* enough to hold a record. C has no way */
/* of checking this.                     */
/*                                       */
/* On entry:                             */
/*  BUFFER: The buffer to hold the       */
/*          record.                      */
/*                                       */
/* Returns:                              */
/*  the length of the record.            */
/*                                       */
/* History:                              */
/*  Begun: 5/86 - Todd King              */
/*            Under GH06 support.        */
/*---------------------------------------*/
srecord(buffer)
char buffer[];
{
  extern char *Rbuffer;
  extern int Recl;

  int i;

  for(i=0;i<Recl;i++) buffer[i]=Rbuffer[i];
  return(Recl);
}
