/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)stdvarsc.h	1.5    (UCLA/IGPP)    08 Feb 1995
 */
/* Declaration of global variables used by pipe calls */
/* Written: 2/10/87 - Todd King   */
/*	Under GG44 support.       */
/* Modified: 6/9/87 - Marco Zagha */
/* Descriptors_written variable added */
/*	Under GG44 support.       */
/* Modified: 12-8-92 -Gilbert Hyatt */
/*      Added support for buffer lib */
/* Modified: 5/12/93 - Gilbert Hyatt */
/*      added DefTimeStyle.          */

#ifndef _STDVARS_
#define _STDVARS_

#include "maxpipec.h"
#include "stddescc.h"
#include "buf_list.h"

DESC Desc[MAXCOLS];

int          Ndesc = 0;
int	     Recl = -1;
int          Next_rbyte = 0;
int          Next_start = 0;
int          Descriptors_written = 0;

BUFFER_HEAD  _Rbuffer;
char         *Rbuffer;
char          Sbuffer[10000];

int  DefTimeStyle = -1; /* used by getcolstr, ffget_col_str, etc.. */
                        /* when handling time columns              */
 
#define DFS_STD_DATA_IN  (3)
#define DFS_STD_DATA_OUT (4)
#define DFS_STD_DATA_ERR (5)

int           datain  = DFS_STD_DATA_IN;
int           dataout = DFS_STD_DATA_OUT;
int           errlog  = DFS_STD_DATA_ERR;
#define _DFS_FD_ 

#endif /* _STDVARS_ */




