/*----------------------------------------------------------------
   Copyright (c) 1992 Regents of the University of California
                 All Rights Reserved

   Development History:
      Begun: 12/02/91 - Todd King

   Version:
      @(#)list.h	1.3   (UCLA/IGPP)   08 Apr 1994
------------------------------------------------------------------*/
#ifndef _list_h_
#define _list_h_	1

typedef struct LIST_NODE {
   char *id;
   char *data;
   struct LIST_NODE *next;
} LIST_NODE;

LIST_NODE *list_make_node();
LIST_NODE *list_find_node();
LIST_NODE *list_insert_node();
LIST_NODE *list_push_node();
LIST_NODE *list_pop_node();
char *list_get_data();

#endif /* _list_h_ */
