/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)specialc.h	1.1    (UCLA/IGPP)     1/8/92
 */
/* Definition of special constants  */
/* written: 8/14/86 - Todd King     */
/* Changes: 2/26/87 - Marco Zagha   */
/* Bug notes: 2/26/87 - Todd King   */
#ifndef _SPECIAL_
#define _SPECIAL_


/* Check if previously defined - some other includes do define
   TRUE and FALSE - accept those definitions.
*/

#ifndef FALSE
#define FALSE   0
#endif /* FALSE */

#ifndef TRUE
#define TRUE    1
#endif /* TRUE */

#define DIRMAXFILES     256     /* For 'dir' function */

#endif /* _SPECIAL_ */
