/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/

/*-- SCASEDOWN -------------------------------*/
/* Converts a given string to all lowercase   */
/* Returns the length of the string converted */
/* Note: On the Sun the following include     */ 
/* statement must be included:                */ 
/*     #include <ctype.h>                     */ 
/*                                            */
/* Development History:                       */
/*  Begun: 6/21/88 - Marco Zagha              */ 
/*            Under GY44 support.             */
/*                                            */
/*  Version:                                  */
/*     @(#)scasedwn.c	1.1      (UCLA/IGPP)     03 Mar 1992           */
/*--------------------------------------------*/

#include <ctype.h> /* For isupper() and tolower() */
#include <string.h>	/* For strlen() */

scasedown(string)
char string[];
{
  int j,end;

  end=strlen(string);
  for(j=0;j<end;j++) if (isupper(string[j])) string[j]=tolower(string[j]);
  return(end);
}

