/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      @(#)more.c	1.1   (UCLA/IGPP)   11 Dec 1992
 */

/* -- START_MORE ------------------------------------------- */
/* Opens a pipe to 'more' to show output a screenful at a    */
/* time.                                                     */
/*                                                           */
/* ENTRY REQUIREMENTS:                                       */
/*   MORE_PTR:  Pointer to a file pointer.                   */
/*                                                           */
/* RETURN VALUES:                                            */
/*   1 if successful starting more; 0 otherwise.             */
/*   Results of popen returned through the parameters.       */
/*                                                           */
/*      Development History:                                 */
/*              Begun:  1/20/87 - Marco Zagha                */
/*                   Under GG44 support                      */
/* --------------------------------------------------------- */
#include <stdio.h>
start_more(more_ptr)
FILE	**more_ptr;
{
FILE		*popen();

  *more_ptr = popen("/usr/ucb/more", "w");
  if (*more_ptr == NULL)
      return(0);
  else return(1);
}

