# Installation Options:
#DFSHOME	= /usr/local/dfs
DEFTEMP 	= /tmp

# DFS Variabbles:
DFSINC		= $(DFSHOME)/include 
DFSINCPROTOS	= $(DFSINC)/Protos
DFSLIB		= $(DFSHOME)/lib/obj
DFSLIBSRC	= $(DFSHOME)/lib/src
FITBIN		= $(DFSHOME)/fittings/bin
FITSOURCE	= $(DFSHOME)/fittings/src
DFSBIN		= $(DFSHOME)/bin
# DFS (Version 2) Variables:
DFSV2HOME	= $(DFSHOME)/V2
DFSV2INC	= $(DFSV2HOME)/include
DFSV2INCPROTOS	= $(DFSV2INC)/Protos
DFSV2LIB	= $(DFSV2HOME)/lib/obj
DFSV2LIBSRC     = $(DFSV2HOME)/lib/src
DFSV2BIN	= $(DFSV2HOME)/bin

# IGPP variables
IGPPINC		= $(SOFTWARE)/igpp/include
IGPPLIB		= $(SOFTWARE)/igpp/lib
IGPPBIN		= $(SOFTWARE)/igpp/bin
IGPPSRC		= $(SOFTWARE)/igpp/src/lib

# X windows Variables:
MOTIFINC	= -I$(MOTIFHOME)/include
MOTIFLIB	= -L$(MOTIFHOME)/lib -lXm
OPENWININC	= 
OPENWINLIB	= -lXol
ATHENAINC	=
ATHENALIB	= -lXaw
TOOLKITINC	=
TOOLKITLIB	=

STDXDIR		= $(OPENWINHOME)
STDXINC		= -I$(STDXDIR)/include
STDXLIBDIR	= -L$(STDXDIR)/lib 
STDXLIBS	= -lXt -lX11
# X libraries to use as standards
XINCS		= $(STDXINC)    $(TOOLKITINC)
XLIBS		= $(STDXLIBDIR) $(TOOLKITLIB) $(STDXLIBS)

# C Language Options:
CC		= cc
#CGENCFLAG	= -g -H -V -xF
CGENCFLAG	= -Xs -g
#CGENCFLAG	= -Xs -g -xO2
RFLAGS		= -R/usr/openwin/lib:/opt/SUNWspro/lib:/usr/local/lib
CFLAGS		= $(MYFLAGS) $(CGENCFLAG) -I$(DFSINC) -I$(DFSV2INC) $(XINCS) \
		  -DDFSHOME="\"$(DFSHOME)\"" -DDFSTEMP="\"$(DEFTEMP)\"" \
		  $(RFLAGS)
CCLOCAL		= -lsocket -lnsl -lm
CFLOCAL		= -lM77 -lF77 -lm
GCC		= gcc -traditional
# F77 Language Options:
FC		= f77
#FGENFFLAG	= -g  -V
FGENFFLAG	= -g  -w
FFLAGS		= $(FGENFFLAG) -I$(IGPPINC) -I$(DFSINC) -I$(DFSV2INC) 
STDFLIBS	= -lF77 -lm
FFLOCAL		= 
# Library Options (C and F77):
LDFLAGS		= -L$(IGPPLIB) -L$(DFSLIB) -L$(DFSV2LIB)

# System Options:
AR		= ar
ARFLAGS		= rv
RANLIB	 	= echo
RM		= rm -f
#MAKE		= /opt/gnu/bin/make 
MAKE		= make
SRC_CNTL	= rcs 
SRC_CNTL_OPT	= 




