/*---------------------------------------------------------------*/
/*   Copyright (c) 1988 Regents of the University of California  */
/*                 All Rights Reserved                           */
/*---------------------------------------------------------------*/
/*
      %W%    (UCLA/IGPP)    %G%
 */
/* declarations for command line processing */
/* begun - 7/24/86 - Marco Zagha */
/* update - 2/6/87 - Marco Zagha */

#include <stdio.h>
  extern int pdbArgNumber;
  extern int pdbFittingID;
  extern int pdbMessageID;
  extern char pdbprefix[40];
  extern int pdbchk_prefix;
  extern int pdboptfile;
  extern char pdbOptName[80];
  extern FILE *pdbcomfile;

#ifndef _DFS_FD_
  extern  int datain;
  extern  int dataout;
  extern  int errlog;
#endif  /* // _DFS_FD_ */

